@@ -93,30 +93,30 @@ class InlineditNonRegressionTC(CubicWebTC):
 
     def test_outputs(self):
         output = self.c.view('reledit', rtype='name')
-        expected = """<div id="name-subject-750-reledit" onmouseout="jQuery('#name-subject-750').addClass('hidden')" onmouseover="jQuery('#name-subject-750').removeClass('hidden')" class="releditField">
-  <div id="name-subject-750-value" class="editableFieldValue">France</div>
-  <div id="name-subject-750" class="editableField hidden">
-    <div id="name-subject-750-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;subject&quot;, &quot;eid&quot;: 750, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;name&quot;, &quot;action&quot;: &quot;edit-rtype&quot;, &quot;divid&quot;: &quot;name-subject-750&quot;});" title="click to edit this field">
+        expected = """<div id="name-subject-%(eid)s-reledit" onmouseout="jQuery('#name-subject-%(eid)s').addClass('hidden')" onmouseover="jQuery('#name-subject-%(eid)s').removeClass('hidden')" class="releditField">
+  <div id="name-subject-%(eid)s-value" class="editableFieldValue">France</div>
+  <div id="name-subject-%(eid)s" class="editableField hidden">
+    <div id="name-subject-%(eid)s-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;subject&quot;, &quot;eid&quot;: %(eid)s, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;name&quot;, &quot;action&quot;: &quot;edit-rtype&quot;, &quot;divid&quot;: &quot;name-subject-%(eid)s&quot;});" title="click to edit this field">
       <img title="click to edit this field" src="http://testing.fr/cubicweb/data/pen_icon.png" alt="click to edit this field"/>
     </div>
   </div>
 </div>"""
-        self.assertSameHtml(expected, output)
+        self.assertSameHtml(expected % {'eid': self.c.eid}, output)
 
         computed = self.c.view('reledit', rtype='partof', role='object')
-        self.assertSameHtml("""<div id="partof-object-750-reledit" onmouseout="jQuery('#partof-object-750').addClass('hidden')" onmouseover="jQuery('#partof-object-750').removeClass('hidden')" class="releditField">
-  <div id="partof-object-750-value" class="editableFieldValue">
+        self.assertSameHtml("""<div id="partof-object-%(eid)s-reledit" onmouseout="jQuery('#partof-object-%(eid)s').addClass('hidden')" onmouseover="jQuery('#partof-object-%(eid)s').removeClass('hidden')" class="releditField">
+  <div id="partof-object-%(eid)s-value" class="editableFieldValue">
     <div class="edit-related-entity">
       <div class="edit-related-entity-item">
-        <div id="none-none-751-reledit" onmouseout="jQuery('#none-none-751').addClass('hidden')" onmouseover="jQuery('#none-none-751').removeClass('hidden')" class="releditField">
-          <div id="none-none-751-value" class="editableFieldValue">
-            <a href="http://testing.fr/cubicweb/region/751" title="">Idf</a>
+        <div id="none-none-%(reid)s-reledit" onmouseout="jQuery('#none-none-%(reid)s').addClass('hidden')" onmouseover="jQuery('#none-none-%(reid)s').removeClass('hidden')" class="releditField">
+          <div id="none-none-%(reid)s-value" class="editableFieldValue">
+            <a href="http://testing.fr/cubicweb/region/%(reid)s" title="">Idf</a>
           </div>
-          <div id="none-none-751" class="editableField hidden">
-            <div id="none-none-751-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;container&quot;: 750, &quot;divid&quot;: &quot;none-none-751&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;topleveldiv&quot;: &quot;partof-object-750&quot;, &quot;role&quot;: &quot;object&quot;, &quot;reload&quot;: false, &quot;fname&quot;: &quot;edit_related_form&quot;, &quot;action&quot;: &quot;edit-related&quot;, &quot;eid&quot;: 751});" title="click to edit this field">
+          <div id="none-none-%(reid)s" class="editableField hidden">
+            <div id="none-none-%(reid)s-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;container&quot;: %(eid)s, &quot;divid&quot;: &quot;none-none-%(reid)s&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;topleveldiv&quot;: &quot;partof-object-%(eid)s&quot;, &quot;role&quot;: &quot;object&quot;, &quot;reload&quot;: false, &quot;fname&quot;: &quot;edit_related_form&quot;, &quot;action&quot;: &quot;edit-related&quot;, &quot;eid&quot;: %(reid)s});" title="click to edit this field">
               <img title="click to edit this field" src="http://testing.fr/cubicweb/data/pen_icon.png" alt="click to edit this field"/>
             </div>
-            <div id="none-none-751-delete" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;container&quot;: 750, &quot;divid&quot;: &quot;none-none-751&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;topleveldiv&quot;: &quot;partof-object-750&quot;, &quot;role&quot;: &quot;object&quot;, &quot;reload&quot;: false, &quot;fname&quot;: &quot;edit_related_form&quot;, &quot;action&quot;: &quot;delete-related&quot;, &quot;eid&quot;: 751});" title="click to delete this value">
+            <div id="none-none-%(reid)s-delete" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;container&quot;: %(eid)s, &quot;divid&quot;: &quot;none-none-%(reid)s&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;topleveldiv&quot;: &quot;partof-object-%(eid)s&quot;, &quot;role&quot;: &quot;object&quot;, &quot;reload&quot;: false, &quot;fname&quot;: &quot;edit_related_form&quot;, &quot;action&quot;: &quot;delete-related&quot;, &quot;eid&quot;: %(reid)s});" title="click to delete this value">
               <img title="click to delete this value" src="http://testing.fr/cubicweb/data/cancel.png" alt="click to delete this value"/>
             </div>
           </div>
@@ -124,27 +124,27 @@ class InlineditNonRegressionTC(CubicWebTC):
       </div>
     </div>
   </div>
-  <div id="partof-object-750" class="editableField hidden">
-    <div id="partof-object-750-add" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;object&quot;, &quot;eid&quot;: 750, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;action&quot;: &quot;add-related&quot;, &quot;divid&quot;: &quot;partof-object-750&quot;});" title="click to add a value">
+  <div id="partof-object-%(eid)s" class="editableField hidden">
+    <div id="partof-object-%(eid)s-add" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;object&quot;, &quot;eid&quot;: %(eid)s, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;partof&quot;, &quot;action&quot;: &quot;add-related&quot;, &quot;divid&quot;: &quot;partof-object-%(eid)s&quot;});" title="click to add a value">
       <img title="click to add a value" src="http://testing.fr/cubicweb/data/plus.png" alt="click to add a value"/>
     </div>
   </div>
 </div>
-""", computed)
+"""  % {'eid': self.c.eid, 'reid': self.r.eid}, computed)
 
         computed = self.c.view('reledit', rtype='spoken_in', role='object')
 
-        self.assertSameHtml("""<div id="spoken_in-object-750-reledit" onmouseout="jQuery('#spoken_in-object-750').addClass('hidden')" onmouseover="jQuery('#spoken_in-object-750').removeClass('hidden')" class="releditField">
-  <div id="spoken_in-object-750-value" class="editableFieldValue">
-    <a href="http://testing.fr/cubicweb/language/752" title="">Fran&#231;ais</a>
+        self.assertSameHtml("""<div id="spoken_in-object-%(eid)s-reledit" onmouseout="jQuery('#spoken_in-object-%(eid)s').addClass('hidden')" onmouseover="jQuery('#spoken_in-object-%(eid)s').removeClass('hidden')" class="releditField">
+  <div id="spoken_in-object-%(eid)s-value" class="editableFieldValue">
+    <a href="http://testing.fr/cubicweb/language/%(languageeid)s" title="">Fran&#231;ais</a>
   </div>
-  <div id="spoken_in-object-750" class="editableField hidden">
-    <div id="spoken_in-object-750-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;object&quot;, &quot;eid&quot;: 750, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;spoken_in&quot;, &quot;action&quot;: &quot;edit-rtype&quot;, &quot;divid&quot;: &quot;spoken_in-object-750&quot;});" title="click to edit this field">
+  <div id="spoken_in-object-%(eid)s" class="editableField hidden">
+    <div id="spoken_in-object-%(eid)s-update" class="editableField" onclick="cw.inlinedit.loadInlineForm({&quot;reload&quot;: false, &quot;role&quot;: &quot;object&quot;, &quot;eid&quot;: %(eid)s, &quot;fname&quot;: &quot;reledit_form&quot;, &quot;rtype&quot;: &quot;spoken_in&quot;, &quot;action&quot;: &quot;edit-rtype&quot;, &quot;divid&quot;: &quot;spoken_in-object-%(eid)s&quot;});" title="click to edit this field">
       <img title="click to edit this field" src="http://testing.fr/cubicweb/data/pen_icon.png" alt="click to edit this field"/>
     </div>
   </div>
 </div>
-""", computed)
+""" % {'eid': self.c.eid, 'languageeid': self.l1.eid}, computed)
 
 
 if __name__ == '__main__':
