@@ -119,7 +119,7 @@ class AutoClickAndEditFormView(EntityView):
         """display field to edit entity's `rtype` relation on click"""
         assert rtype
         self._cw.add_css('cubicweb.form.css')
-        self._cw.add_js('cubes.inlinedit.js', 'cubicweb.edition.js')
+        self._cw.add_js(('cubicweb.ajax.js', 'cubes.inlinedit.js', 'cubicweb.edition.js'))
         self.entity = entity
         rschema = self._cw.vreg.schema[rtype]
         self._rules = rctrl.etype_get(self.entity.e_schema.type, rschema.type, role, '*')
